"""
MyAnimeList API wrapper
~~~~~~~~~~~~~~~~~~~~~~~

Simple wrapper for the MyAnimeList API.

:copyright: (c) 2022 Skylake-dev
:license: MIT, see LICENSE for more details
"""

__title__ = 'mal'
__author__ = 'Skylake-dev'
__license__ = 'MIT'
__version__ = '0.5.1'

import logging

logging.getLogger(__name__).addHandler(logging.NullHandler())

del logging